# friendly-traceback
Aimed at Python beginners: replacing standard traceback by something easier to understand, translatable into various languages.

![Example](https://raw.githubusercontent.com/aroberge/friendly-traceback/master/why_1.png)

## Installation

```
pip install friendly-traceback
```

## Documentation


[Full documentation available here](https://aroberge.github.io/friendly-traceback-docs/docs/html/)

![Example](https://raw.githubusercontent.com/aroberge/friendly-traceback/master/explain.png)


## Contribute

See the documentation. Note that Friendly-traceback uses Black.
![Black logo](https://img.shields.io/badge/code%20style-black-000000.svg)

Some of the ideas were adopted from
[DidYouMean-Python (aka BetterErrorMessages)](https://github.com/SylvainDe/DidYouMean-Python)
by Sylvain Desodt, a project that is also using the MIT license.

## Code of Conduct

We support the
[Python Community Code of Conduct](https://www.python.org/psf/codeofconduct/).
Contributors to this project, including those filing or commenting on an issue,
are expected to do the same.

